package App::rsynccolor;

our $DATE = '2019-05-06'; # DATE
our $VERSION = '0.006'; # VERSION

1;
# ABSTRACT: Add some color to rsync output

__END__

=pod

=encoding UTF-8

=head1 NAME

App::rsynccolor - Add some color to rsync output

=head1 VERSION

This document describes version 0.006 of App::rsynccolor (from Perl distribution App-rsynccolor), released on 2019-05-06.

=head1 SYNOPSIS

See the command-line script L<rsynccolor>.

=head1 DESCRIPTION

Sample screenshot:

=for Pod::Coverage ^(.+)$

=for html <img src="https://st.aticpan.org/source/PERLANCAR/App-rsynccolor-0.006/share/images/Screenshot_20190506_181519.png" />

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-rsynccolor>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-rsynccolor>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-rsynccolor>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2019, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
